pub struct FeatureSnapshot {Show 71 fields
pub blake3_syscall_enabled: bool,
pub disable_fees_sysvar: bool,
pub curve25519_syscall_enabled: bool,
pub stake_raise_minimum_delegation_to_1_sol: bool,
pub disable_deploy_of_alloc_free_syscall: bool,
pub increase_tx_account_lock_limit: bool,
pub enable_bpf_loader_set_authority_checked_ix: bool,
pub enable_alt_bn128_syscall: bool,
pub simplify_alt_bn128_syscall_error_codes: bool,
pub enable_big_mod_exp_syscall: bool,
pub remove_bpf_loader_incorrect_program_id: bool,
pub syscall_parameter_address_restrictions: bool,
pub virtual_address_space_adjustments: bool,
pub account_data_direct_mapping: bool,
pub last_restart_slot_sysvar: bool,
pub enable_poseidon_syscall: bool,
pub remaining_compute_units_syscall_enabled: bool,
pub enable_alt_bn128_compression_syscall: bool,
pub abort_on_invalid_curve: bool,
pub get_sysvar_syscall_enabled: bool,
pub enable_get_epoch_stake_syscall: bool,
pub move_stake_and_move_lamports_ixs: bool,
pub move_precompile_verification_to_svm: bool,
pub deprecate_legacy_vote_ixs: bool,
pub disable_sbpf_v0_execution: bool,
pub reenable_sbpf_v0_execution: bool,
pub enable_sbpf_v1_deployment_and_execution: bool,
pub enable_sbpf_v2_deployment_and_execution: bool,
pub enable_sbpf_v3_deployment_and_execution: bool,
pub disable_sbpf_v0_v1_v2_deployment: bool,
pub deplete_cu_meter_on_vm_failure: bool,
pub fix_alt_bn128_multiplication_input_length: bool,
pub formalize_loaded_transaction_data_size: bool,
pub alpenglow: bool,
pub alpenglow_fast_leader_handover: bool,
pub disable_zk_elgamal_proof_program: bool,
pub reenable_zk_elgamal_proof_program: bool,
pub raise_block_limits_to_100m: bool,
pub raise_cpi_nesting_limit_to_8: bool,
pub provide_instruction_data_offset_in_vm_r2: bool,
pub create_account_allow_prefund: bool,
pub delay_commission_updates: bool,
pub increase_cpi_account_info_limit: bool,
pub deprecate_rent_exemption_threshold: bool,
pub poseidon_enforce_padding: bool,
pub fix_alt_bn128_pairing_length_check: bool,
pub alt_bn128_little_endian: bool,
pub bls_pubkey_management_in_vote_account: bool,
pub relax_programdata_account_check_migration: bool,
pub enable_alt_bn128_g2_syscalls: bool,
pub commission_rate_in_basis_points: bool,
pub custom_commission_collector: bool,
pub enable_bls12_381_syscall: bool,
pub set_lamports_per_byte_to_6333: bool,
pub set_lamports_per_byte_to_5080: bool,
pub set_lamports_per_byte_to_2575: bool,
pub set_lamports_per_byte_to_1322: bool,
pub limit_instruction_accounts: bool,
pub block_revenue_sharing: bool,
pub vote_account_initialize_v2: bool,
pub validate_chained_block_id: bool,
pub validator_admission_ticket: bool,
pub direct_account_pointers_in_program_input: bool,
pub upgrade_bpf_stake_program_to_v5: bool,
pub loader_v3_minimum_extend_program_size: bool,
pub enable_sha512_syscall: bool,
pub relax_post_exec_min_balance_check: bool,
pub enable_tx_v1: bool,
pub define_ltds_fee_only_semantics: bool,
pub validate_chained_block_id_2: bool,
pub upgrade_bpf_stake_program_to_v5_1: bool,
}Expand description
A snapshot of features for faster access without a hash lookup.
It should contain only features that have not been activated on
all clusters.
The order of fields should match the declaration order in
FEATURE_NAMES.
Fields
blake3_syscall_enabled: booldisable_fees_sysvar: boolcurve25519_syscall_enabled: boolstake_raise_minimum_delegation_to_1_sol: booldisable_deploy_of_alloc_free_syscall: boolincrease_tx_account_lock_limit: boolenable_alt_bn128_syscall: boolsimplify_alt_bn128_syscall_error_codes: boolenable_big_mod_exp_syscall: boolremove_bpf_loader_incorrect_program_id: boolsyscall_parameter_address_restrictions: boolvirtual_address_space_adjustments: boolaccount_data_direct_mapping: boollast_restart_slot_sysvar: boolenable_poseidon_syscall: boolremaining_compute_units_syscall_enabled: boolenable_alt_bn128_compression_syscall: boolabort_on_invalid_curve: boolget_sysvar_syscall_enabled: boolenable_get_epoch_stake_syscall: boolmove_stake_and_move_lamports_ixs: boolmove_precompile_verification_to_svm: booldeprecate_legacy_vote_ixs: booldisable_sbpf_v0_execution: boolreenable_sbpf_v0_execution: boolenable_sbpf_v1_deployment_and_execution: boolenable_sbpf_v2_deployment_and_execution: boolenable_sbpf_v3_deployment_and_execution: booldisable_sbpf_v0_v1_v2_deployment: booldeplete_cu_meter_on_vm_failure: boolfix_alt_bn128_multiplication_input_length: boolformalize_loaded_transaction_data_size: boolalpenglow: boolalpenglow_fast_leader_handover: booldisable_zk_elgamal_proof_program: boolreenable_zk_elgamal_proof_program: boolraise_block_limits_to_100m: boolraise_cpi_nesting_limit_to_8: boolprovide_instruction_data_offset_in_vm_r2: boolcreate_account_allow_prefund: booldelay_commission_updates: boolincrease_cpi_account_info_limit: booldeprecate_rent_exemption_threshold: boolposeidon_enforce_padding: boolfix_alt_bn128_pairing_length_check: boolalt_bn128_little_endian: boolbls_pubkey_management_in_vote_account: boolrelax_programdata_account_check_migration: boolenable_alt_bn128_g2_syscalls: boolcommission_rate_in_basis_points: boolcustom_commission_collector: boolenable_bls12_381_syscall: boolset_lamports_per_byte_to_6333: boolset_lamports_per_byte_to_5080: boolset_lamports_per_byte_to_2575: boolset_lamports_per_byte_to_1322: boollimit_instruction_accounts: boolblock_revenue_sharing: boolvote_account_initialize_v2: boolvalidate_chained_block_id: boolvalidator_admission_ticket: booldirect_account_pointers_in_program_input: boolupgrade_bpf_stake_program_to_v5: boolloader_v3_minimum_extend_program_size: boolenable_sha512_syscall: boolrelax_post_exec_min_balance_check: boolenable_tx_v1: booldefine_ltds_fee_only_semantics: boolvalidate_chained_block_id_2: boolupgrade_bpf_stake_program_to_v5_1: boolTrait Implementations
Sourceimpl Clone for FeatureSnapshot
impl Clone for FeatureSnapshot
Sourcefn clone(&self) -> FeatureSnapshot
fn clone(&self) -> FeatureSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeatureSnapshot
impl Debug for FeatureSnapshot
impl Eq for FeatureSnapshot
Sourceimpl PartialEq for FeatureSnapshot
impl PartialEq for FeatureSnapshot
impl StructuralPartialEq for FeatureSnapshot